==> haskell-data-endian-0.1.1-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-endian.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-endian
version:              0.1.1
visibility:           public
id:                   data-endian-0.1.1-5ELABUSHRCN9Wd3DzqzD6m
key:                  data-endian-0.1.1-5ELABUSHRCN9Wd3DzqzD6m
license:              BSD-3-Clause
copyright:            2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-endian
synopsis:             Endian-sensitive data
description:
    This package provides helpers for converting endian-sensitive data.

category:             Data
abi:                  475654afc06ccdfc9ac0dff5bf843b33
exposed:              True
exposed-modules:      Data.Endian
import-dirs:          /usr/lib/ghc-8.10.4/site-local/data-endian-0.1.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/data-endian-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/data-endian-0.1.1
hs-libraries:         HSdata-endian-0.1.1-5ELABUSHRCN9Wd3DzqzD6m
depends:              base-4.14.1.0
haddock-interfaces:   /usr/share/doc/haskell-data-endian/html/data-endian.haddock
haddock-html:         /usr/share/doc/haskell-data-endian/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-endian-0.1.1-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-endian.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-endian
version:              0.1.1
visibility:           public
id:                   data-endian-0.1.1-8ECaUQ9v55RAjAwuwWbvWN
key:                  data-endian-0.1.1-8ECaUQ9v55RAjAwuwWbvWN
license:              BSD-3-Clause
copyright:            2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-endian
synopsis:             Endian-sensitive data
description:
    This package provides helpers for converting endian-sensitive data.

category:             Data
abi:                  ed283de2fe4b896be912b3069295e4bc
exposed:              True
exposed-modules:      Data.Endian
import-dirs:          /usr/lib/ghc-8.10.5/site-local/data-endian-0.1.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/data-endian-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/data-endian-0.1.1
hs-libraries:         HSdata-endian-0.1.1-8ECaUQ9v55RAjAwuwWbvWN
depends:              base-4.14.2.0
haddock-interfaces:   /usr/share/doc/haskell-data-endian/html/data-endian.haddock
haddock-html:         /usr/share/doc/haskell-data-endian/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
